@@ -1,5 +1,5 @@
 package App::Deps::Verify::App::VerifyDeps;
-$App::Deps::Verify::App::VerifyDeps::VERSION = '0.8.3';
+$App::Deps::Verify::App::VerifyDeps::VERSION = '0.10.0';
 use strict;
 use warnings;
 use autodie;
@@ -14,15 +14,11 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-App::Deps::Verify::App::VerifyDeps
-
 =head1 VERSION
 
-version 0.8.3
+version 0.10.0
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -59,14 +55,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Deps-Verify>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Deps-Verify>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
